@@ -117,10 +117,10 @@ class TransmissionBase(object):
                 seed_limit_ok = torrent.uploadRatio >= session.seedRatioLimit
 
         if torrent.seedIdleMode == 1:  # use torrent's own idle limit
-            idle_limit_ok = torrent.activityDate + timedelta(minutes=torrent.seedIdleLimit) < datetime.now()
+            idle_limit_ok = torrent.date_active + timedelta(minutes=torrent.seedIdleLimit) < datetime.now()
         elif torrent.seedIdleMode == 0:  # use global rules
             if session.idle_seeding_limit_enabled:
-                idle_limit_ok = torrent.activityDate + timedelta(minutes=session.idle_seeding_limit) < datetime.now()
+                idle_limit_ok = torrent.date_active + timedelta(minutes=session.idle_seeding_limit) < datetime.now()
 
         return seed_limit_ok, idle_limit_ok
 
